<?php

/**
 * @file
 * Delete all Drush command.
 */

use Drupal\media_delete_all\Controller\MediaDeleteController;

/**
 * Implements hook_drush_command().
 *
 * Delete All Media.
 * delete-all-delete-media (dadm)
 *   - Command to delete media. *
 *   - "--type" is an optional parameter here and provides the option to delete
 *       all medias of a type specified in the command. *
 *   - Following are the possible ways to use the command: *
 *     1. `drush dadm`
 *          - Deletes all media of all types.
 *     2. `drush dadm --type`
 *          - User can choose one of the media type from the options given.
 *            All media of that type will be deleted.
 *     3. `drush dadm --type type_1,type_2,type_3`
 *          - All media with either of the given types will be deleted.
 *            Please note that machine name of the media type must be
 *            provided. Two media types should be separed only by a 'comma'
 *            without any space before or after the comma.
 */
function media_delete_all_drush_command() {
  $items = [];
  $items['delete-all-delete-media'] = [
    'description' => 'Delete media.',
    'options' => [
      'type' => 'pick media type',
    ],
    'examples' => [
      'drush delete-all-delete-media' => 'Delete media.',
    ],
    'aliases' => ['dadm'],
  ];

  return $items;
}

/**
 * Drush callback to delete media.
 */
function drush_delete_all_delete_media() {
  // Initialize $media_type_options as FALSE to specify that all
  // media of all types should be deleted.
  // This will be overriden if user provides/choses a media type.
  $media_type_options = FALSE;

  $deletemedia = new MediaDeleteController();

  // Check for presence of '--type' in drush command.
  if (drush_get_option('type')) {
    // func_get_args() collects all keywords separated by space in an array.
    // To get the media types, we join all the keywords in a string and then
    // use 'comma' to separate them.
    $types = func_get_args();
    if ($types) {
      $media_types = implode(' ', $types);
      if (strpos($media_types, ',')) {
        $media_type_options = explode(',', $media_types);
      }
      else {
        $media_type_options = [$media_types];
      }
    }
    // Output all media types on screen and ask user to choose one.
    else {
      $media_type_options = [];
      $media_types = \Drupal::entityTypeManager()->getStorage('media_type')->loadMultiple();
      foreach ($media_types as $media_type_machine_name => $media_type) {
        $choices[$media_type_machine_name] = $media_type->label();
      }

      $media_type_options = drush_choice($choices, dt("Choose a media type to delete. All media of this"));

      // Return if no role is chosen.
      if ($media_type_options === 0 || $media_type_options === FALSE) {
        drush_user_abort();
        return;
      }
      $media_type_options = [$media_type_options];
    }
  }

  if (drush_confirm('Are you sure you want to delete the media?')) {
    // Get media to delete.
    $medias_to_delete = $deletemedia->getMediaToDelete($media_type_options);

    // Get batch array.
    $batch = $deletemedia->getMediatDeleteBatch($medias_to_delete);

    // Initialize the batch.
    batch_set($batch);

    // Start the batch process.
    drush_backend_batch_process();
  }
  else {
    drush_user_abort();
  }

}
